@@ -1,5 +1,5 @@
 package Bot::Cobalt::Logger;
-$Bot::Cobalt::Logger::VERSION = '0.017002';
+$Bot::Cobalt::Logger::VERSION = '0.017003';
 use strictures 2;
 use Carp;
 
@@ -66,11 +66,8 @@ sub _build_output {
 
   my %opts;
 
-  $opts{log_format} = $self->log_format
-    if $self->has_log_format;
-
-  $opts{time_format} = $self->time_format
-    if $self->has_time_format;
+  $opts{log_format}  = $self->log_format  if $self->has_log_format;
+  $opts{time_format} = $self->time_format if $self->has_time_format;
 
   Bot::Cobalt::Logger::Output->new(
     %opts
@@ -108,7 +105,6 @@ sub warn  { shift->_log_to_level( 'warn', @_ )  }
 sub error { shift->_log_to_level( 'error', @_ ) }
 
 1;
-__END__
 
 =pod
 
